function [ qrs_ind ] = detect_qrs( ecg_signal, samplerate )
%DETECT_QRS Detects QRS complexes in Signals
%   Detects QRS complexes in the provided vector
%   "ecg_signal" that contains an ecg signal sampled
%   at "samplerate"

    if ( ~isnumeric(ecg_signal) || any(isnan(ecg_signal)) || ...
         ~isvector(ecg_signal) || length(ecg_signal) <= 1 )
        error('detect_qrs:invalid_ecg_signal', ...
              'ecg_signal must be a numeric vector');
    end

    if ( ~isnumeric(samplerate) || isnan(samplerate) || ...
         isempty(samplerate) || samplerate < 0 )
        error('detect_qrs:invalid_samplerate', ...
              'samplerate must be a positive non-zero integer');
    end

    gradient_spacing = max(round(0.012 * samplerate), 1);
    min_peak_height =  0.03 * gradient_spacing;
    min_peak_distance = floor(samplerate * 0.5);



    ecg_gradient = gradient(ecg_signal,gradient_spacing);
    [~, qrs_ind] = findpeaks(ecg_gradient, ...
                             'minpeakheight', min_peak_height, ...
                             'minpeakdistance',min_peak_distance);
end

